#20201009-1621
### Add 2019 support to OS Check
### Add Install-WindowsFeature to 2012+ for Web Roles and Services
### Add Web-Mgmt-Console
### comment out Clear-Content $ServerInfoFile
#20210217-1111
###Add Debug Import URL
###Add Get-ADDomain information to serverinfo.txt


#Find OS
$OSCheck = $OSVersion = (get-itemproperty -Path "HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion" -Name ProductName).ProductName

#Print found OS
Write-Host Current OS is $OSCheck 

#Import needed modulues
import-module ServerManager

#Install correct windows feature for os.  Also does a OS check for Server 

#Windows 2008 check
if  ($OSCheck -like '*2008*') { Add-WindowsFeature Web-Server,Web-Mgmt-Console,Web-Windows-Auth,Web-ASP,Web-ASP-NET}

#Windows 2012 or newer check
elseif  ($OSCheck -like '*201*') { Install-WindowsFeature Web-Server,Web-Mgmt-Console,Web-Windows-Auth,Web-ASP,Web-ASP-Net45,Web-Net-Ext45 }

#Other OS check and exit. 
else { Write-Host "=========================== `r`n Not a supported server OS `r`n==========================="  `r`n -foreground  "magenta" Read-Host ' Press enter to continue...' | Out-Null }

#Create folder 
New-Item -ItemType directory -ErrorAction Ignore -Path "C:\inetpub\wwwroot\securlysso"

#Copy files 
Copy-Item -Path  .\files\* -Destination C:\inetpub\wwwroot\securlysso\ -recurse -ErrorAction SilentlyContinue

#Set IIS settings
C:\windows\system32\inetsrv\appcmd.exe unlock config -section:system.webServer/handlers
C:\windows\system32\inetsrv\appcmd.exe unlock config -section:system.webServer/security/authentication/anonymousAuthentication -commitpath:apphost
C:\windows\system32\inetsrv\appcmd.exe add app /site.name:"Default Web Site" /path:/securlysso /physicalPath:C:\inetpub\wwwroot\securlysso\
C:\windows\system32\inetsrv\appcmd.exe set config "Default Web Site/securlysso" -section:system.webServer/security/authentication/AnonymousAuthentication /enabled:"False"
C:\windows\system32\inetsrv\appcmd.exe unlock config -section:system.webServer/security/authentication/windowsAuthentication -commitpath:apphost
C:\windows\system32\inetsrv\appcmd.exe set config "Default Web Site/securlysso" -section:system.webServer/security/authentication/windowsAuthentication /enabled:"True"

#Reset IIS
iisreset

#get server info

$ServerInfoFile = "c:\inetpub\wwwroot\securlysso\ServerInfo.txt"
$servername = hostname

#Clear-Content $ServerInfoFile - removed
Add-Content $ServerInfoFile "$ServerInfoFile"

Add-Content $ServerInfoFile " "
Add-Content $ServerInfoFile " "

Add-Content $ServerInfoFile "UserName:  $env:UserName"
Add-Content $ServerInfoFile "Hostname:  $servername"
Add-Content $ServerInfoFile "NTLM Domain Name:  $env:UserDomain"
Add-Content $ServerInfoFile "FQDN Domain Name:  $env:USERDNSDOMAIN"

Add-Content $ServerInfoFile " "


Add-Content $ServerInfoFile "Authentication URL: http://$servername/securlysso/securlysso.aspx"
Add-Content $ServerInfoFile "Internal Debug URL: http://$servername/securlysso/debug.aspx"

Add-Content $ServerInfoFile " "

Add-Content $ServerInfoFile "Test OU import URL: http://$servername/securlysso/fetchOus.aspx?domain=securly_test"
Add-Content $ServerInfoFile "Test OU import for this domain URL: http://$servername/securlysso/DebugFetchOus.aspx?domain=$env:USERDNSDOMAIN"

Add-Content $ServerInfoFile " "

Add-Content $ServerInfoFile "Debug OU Import URL: http://$servername/securlysso/DebugImport.aspx?domain=$env:USERDNSDOMAIN"
Add-Content $ServerInfoFile "Debug log found in C:\temp "

Add-Content $ServerInfoFile " "

Add-Content $ServerInfoFile "Global Settings Intranet Address: http://$servername/securlysso"
Add-Content $ServerInfoFile " "

Add-Content $ServerInfoFile "==========================="
Add-Content $ServerInfoFile "IIS Server IP Address Info "
Add-Content $ServerInfoFile "==========================="

Get-NetIPAddress -AddressFamily IPv4 | Select-Object IPAddress | out-file .\iptemp.txt
Get-Content iptemp.txt | Add-Content $ServerInfoFile
Remove-Item .\iptemp.txt 

Add-Content $ServerInfoFile "IIS DNS Server IP Addresses "

Get-DnsClientServerAddress -AddressFamily IPv4 | Select-Object  ServerAddresses | out-file -append .\DNStemp.txt
Get-Content DNStemp.txt| Add-Content $ServerInfoFile
Remove-Item .\DNStemp.txt

Add-Content $ServerInfoFile "==========================="
Add-Content $ServerInfoFile "Active Directory Domain Info "
Add-Content $ServerInfoFile "==========================="

Get-ADDomain | out-file -append .\ADtemp.txt
Get-Content ADtemp.txt| Add-Content $ServerInfoFile
Remove-Item .\ADtemp.txt

#print script completed
Write-Host "Script complete" -foreground  "green"
Read-Host 'Press enter to continue...' | Out-Null 
start C:\inetpub\wwwroot\securlysso
start $ServerInfoFile